#!/bin/bash


diff_inputs() {
    for file in inputs_list.txt $( ls namelist_* ) iodef.xml; do
	diff $file ${REFE_DIR}/$file

	if [ $? -ne 0 ]; then
	    printf "Input files\nDifferent" | tee mesg_09_inputfiles_${CFG_USER}_${CFG_ARCH}.txt
	    get_out
	fi

    done

    printf "Input files\nSame"              | tee mesg_09_inputfiles_${CFG_USER}_${CFG_ARCH}.txt
}

diff_nc() {
    stat=100; file1=$1; file2=$2

    $CDO diffv $file1 $file2 > out_tmp
    ( [ $? -ne 0 ] && stat=100 ) || stat=$( grep -m 1 'records differ' out_tmp | awk -Fof '{print $1}' )
    [ -f out_tmp ] && rm out_tmp

    return $stat
} 

diff_restart() {
    result=0
    last_time_step=$( cat ${REFE_DIR}/time.step | tr -d [:space:] )
    echo 'Last time step: '${last_time_step}

    if [ $( find ${TEST_DIR} -name "*${last_time_step}_restart*.nc" -print -quit ) ]; then
	file_base=$( find ${TEST_DIR} -name "*${last_time_step}_restart*.nc" -print -quit | \
	             sed "s/^\(.*\)0*$last_time_step.*/\1/"                                 )

	for file in restart restart_ice restart_trc; do
	    printf "${TEST_DIR}/*${last_time_step}_${file}*.nc: "

	    nb_dom=$( find ${TEST_DIR} -name "*${last_time_step}_${file}_[0-9]*.nc" | wc -l | awk '{print $1}' )
	    if [ ${nb_dom} -gt 1 ]; then
		${NEMO_TRBD}/rebuild_nemo -t $NPROC ${file_base}${last_time_step}_$file ${nb_dom} >/dev/null
	    fi

#	    result=$( diff_nc ${TEST_DIR}/*${last_time_step}_$file.nc ${REFE_DIR}/*${last_time_step}_$file.nc )
	    result=$( diff_nc ${file_base}${last_time_step}_$file.nc ${REFE_DIR}/*${last_time_step}_$file.nc )
	    printf "$CDO diffv $result\n"
#	    \rm *${last_time_step}_${file}_[0-9]*.nc
	done

    else
	printf "no restart files found for comparison\n"
    fi
}

get_soft_rel() {
    for rel in $CDO $COMPILER $MPI $NETCDF; do
                                arch_rel=$( echo $LOADEDMODULES | sed "s#.*$rel/\([^:]*\).*#\1#" )
	[ -z "${arch_rel}" ] && arch_rel=$( echo $PATH          | sed "s#.*$rel/\([^/]*\).*#\1#" )
	[ $( echo $rel | grep $COMPILER ) ] && arch_rel=$( $rel --version | grep -m1 -o ' [0-9.]* ' )
	echo $rel ${arch_rel} >> model.log
    done
}

get_nemo_rev() {
    rev=0

    for dir in ${DIR_XIOS}  ${NEMO_ARCH} ${NEMO_CONF} ${NEMO_ENGI} ${NEMO_EIOI} \
	       ${NEMO_EFCM} ${NEMO_TRUS} ${NEMO_TCMP} ${NEMO_TRBD}               ; do
	# For time being, just get revision number from XIOS
	[ $dir == ${DIR_XIOS} ] && echo 'XIOS '$( svn info $dir | awk '(NR == 9) {print $NF}' ) >> model.log && continue
	${SVN_CMD} $dir
	rev_loc=$( svn info $dir | awk '(NR == 9) {print $NF}' )
	(( ${rev_loc} >= $rev )) && rev=${rev_loc}
    done

    echo 'NEMO '$rev >> model.log
}

mesg_make() {
    paste -d ';' mesg_*_${CFG_USER}_${CFG_ARCH}.txt > trusting_${DATE_STR}_${CFG_USER}_${CFG_ARCH}.txt
    cat trusting_${DATE_STR}_${CFG_USER}_${CFG_ARCH}.txt
}

mesg_publish() {
  
if [ $PUBLISH -eq 1 ]; then

  if [ -f ${REFE_DIR}/trusting_${CFG_USER}_${CFG_ARCH}.txt ]; then cmd='sed -n 2p'; else cmd='cat'; fi

  $cmd trusting_${DATE_STR}_${CFG_USER}_${CFG_ARCH}.txt >> ${REFE_DIR}/trusting_${CFG_USER}_${CFG_ARCH}.txt

  # Send mail only when FAILED
  if [[ $( grep 'FAILED' mesg_02_status_${CFG_USER}_${CFG_ARCH}.txt ) && ! -z $MAIL ]]; then
      cat << END_MAIL > trusting.mail
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Dear $USER,

The trusting sequence for ${CONF_REF} has failed at step:
`tail -n 1 mesg_03_step_${CFG_USER}_${CFG_ARCH}.txt`
Directory : ${TEST_DIR}

XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

END_MAIL
      cat mesg_*_${CFG_USER}_${CFG_ARCH}.txt        >> trusting.mail
      mail -s "[trusting ${CONF_REF}] FAILED" $MAIL  < trusting.mail
  fi

fi
}

get_out() {
    mesg_make; mesg_publish

    # Save tested configuration if trusting failed
    if [ $status == 'FAILED' ]; then
	cd ${REFE_DIR}
	tar -czf trusting_${DATE_STR}_${CFG_USER}_${CFG_ARCH}.tar.gz ${TEST_DIR}/*
	cd -
    fi
	
    exit 1
}
